@@ -72,6 +72,14 @@ private:
     double * bestLagrange;
     double * rawDataPartition;
     vector < vector < double > > T;
+    vector < vector < double > > Tdx;
+    vector <int> smoothWindow;
+    vector <double> smoothSize;
+    double smoothError;
+    bool smooth;
+    
+    vector <double> A1;
+    vector <double> A2;
     
     void funnelDiffusion(double * original, double * updated, int arraySize, double currentSigmaMu);
     void funnelDiffusion(double * original, double * updated, int arraySize, double currentSigmaMu, int startIndex);
